summaryrefslogtreecommitdiff
path: root/deps/v8/src/debug.cc
diff options
context:
space:
mode:
authorRyan <ry@tinyclouds.org>2009-08-19 16:37:15 +0200
committerRyan <ry@tinyclouds.org>2009-08-19 16:37:15 +0200
commit0cec74d03dc6a1735e731fe06056a1731e14c0df (patch)
tree9606bcb9afeba305a7b2a1ac4c518ded63a25d89 /deps/v8/src/debug.cc
parentb590a45849307f5544b7a95854f45064527105ad (diff)
downloadnode-0cec74d03dc6a1735e731fe06056a1731e14c0df.tar.gz
Upgrade v8 to 1.3.5
Diffstat (limited to 'deps/v8/src/debug.cc')
-rw-r--r--deps/v8/src/debug.cc10
1 files changed, 6 insertions, 4 deletions
diff --git a/deps/v8/src/debug.cc b/deps/v8/src/debug.cc
index 18536f5c7..f2a28148b 100644
--- a/deps/v8/src/debug.cc
+++ b/deps/v8/src/debug.cc
@@ -1452,14 +1452,15 @@ void Debug::SetAfterBreakTarget(JavaScriptFrame* frame) {
// Find the call address in the running code. This address holds the call to
// either a DebugBreakXXX or to the debug break return entry code if the
// break point is still active after processing the break point.
- Address addr = frame->pc() - Assembler::kTargetAddrToReturnAddrDist;
+ Address addr = frame->pc() - Assembler::kPatchReturnSequenceLength;
// Check if the location is at JS exit.
bool at_js_exit = false;
RelocIterator it(debug_info->code());
while (!it.done()) {
if (RelocInfo::IsJSReturn(it.rinfo()->rmode())) {
- at_js_exit = it.rinfo()->pc() == addr - 1;
+ at_js_exit = (it.rinfo()->pc() ==
+ addr - Assembler::kPatchReturnSequenceAddressOffset);
}
it.next();
}
@@ -1477,8 +1478,9 @@ void Debug::SetAfterBreakTarget(JavaScriptFrame* frame) {
addr += original_code->instruction_start() - code->instruction_start();
}
- // Move one byte back to where the call instruction was placed.
- thread_local_.after_break_target_ = addr - 1;
+ // Move back to where the call instruction sequence started.
+ thread_local_.after_break_target_ =
+ addr - Assembler::kPatchReturnSequenceAddressOffset;
} else {
// Check if there still is a debug break call at the target address. If the
// break point has been removed it will have disappeared. If it have